[PATCH] Align cmd.h for merge

May as well merge the header if we've alreay done the source file.

diff -urN a/NQ/cmd.h head/NQ/cmd.h
--- a/NQ/cmd.h	2006-02-25 13:12:38.000000000 +1030
+++ head/NQ/cmd.h	2006-02-26 11:47:45.000000000 +1030
@@ -65,17 +65,9 @@
 //===========================================================================
 
 /*
-
-Command execution takes a null terminated string, breaks it into tokens,
-then searches for a command or variable that matches the first token.
-
-// FIXME - this comment section and enum below not in QW (different behaviour)
-//       - comment in QW explains it grep for QW_CMD_SOURCE
-Commands can come from three sources, but the handler functions may choose
-to dissallow the action or forward it to a remote server if the source is
-not apropriate.
-
-*/
+ * Command execution takes a null terminated string, breaks it into tokens,
+ * then searches for a command or variable that matches the first token.
+ */
 
 /* Command function */
 typedef void (*xcommand_t)(void);
@@ -88,14 +80,34 @@
  */
 typedef struct stree_root *(*cmd_arg_f)(const char *);
 
+#ifdef NQ_HACK
+/*
+ * In NQ, commands can come from three sources, but the handler functions may
+ * choose to dissallow the action or forward it to a remote server if the
+ * source is not apropriate.
+ */
 typedef enum {
-    src_client,			// came in over a net connection as a clc_stringcmd
-    // host_client will be valid during this state.
-    src_command			// from the command buffer
+    src_client,		/* came in over a net connection as a clc_stringcmd
+			   host_client will be valid during this state. */
+    src_command		/* from the command buffer */
 } cmd_source_t;
 
 extern cmd_source_t cmd_source;
 
+/*
+ * Parses a single line of text into arguments and tries to execute it.
+ * The text can come from the command buffer, a remote client, or stdin.
+ */
+void Cmd_ExecuteString(char *text, cmd_source_t src);
+#endif
+#ifdef QW_HACK
+/*
+ * Parses a single line of text into arguments and tries to execute it as if
+ * it was typed at the console
+ */
+void Cmd_ExecuteString(char *text);
+#endif
+
 void Cmd_Init(void);
 
 void Cmd_AddCommand(const char *cmd_name, xcommand_t function);
@@ -132,20 +144,20 @@
 // Takes a null terminated string.  Does not need to be /n terminated.
 // breaks the string up into arg tokens.
 
-void Cmd_ExecuteString(char *text, cmd_source_t src);
-
-// Parses a single line of text into arguments and tries to execute it.
-// The text can come from the command buffer, a remote client, or stdin.
-
 void Cmd_ForwardToServer(void);
 
 // adds the current command line as a clc_stringcmd to the client message.
 // things like godmode, noclip, etc, are commands directed to the server,
 // so when they are typed in at the console, they will need to be forwarded.
 
+#ifdef NQ_HACK
 void Cmd_Print(char *text);
 
 // used by command functions to send output to either the graphics console or
 // passed as a print message to the client
+#endif
+#ifdef QW_HACK
+void Cmd_StuffCmds_f(void);
+#endif
 
 #endif /* CMD_H */
diff -urN a/QW/client/cmd.h head/QW/client/cmd.h
--- a/QW/client/cmd.h	2006-02-25 13:12:38.000000000 +1030
+++ head/QW/client/cmd.h	2006-02-26 11:47:57.000000000 +1030
@@ -65,11 +65,9 @@
 //===========================================================================
 
 /*
-
-Command execution takes a null terminated string, breaks it into tokens,
-then searches for a command or variable that matches the first token.
-
-*/
+ * Command execution takes a null terminated string, breaks it into tokens,
+ * then searches for a command or variable that matches the first token.
+ */
 
 /* Command function */
 typedef void (*xcommand_t)(void);
@@ -82,6 +80,34 @@
  */
 typedef struct stree_root *(*cmd_arg_f)(const char *);
 
+#ifdef NQ_HACK
+/*
+ * In NQ, commands can come from three sources, but the handler functions may
+ * choose to dissallow the action or forward it to a remote server if the
+ * source is not apropriate.
+ */
+typedef enum {
+    src_client,		/* came in over a net connection as a clc_stringcmd
+			   host_client will be valid during this state. */
+    src_command		/* from the command buffer */
+} cmd_source_t;
+
+extern cmd_source_t cmd_source;
+
+/*
+ * Parses a single line of text into arguments and tries to execute it.
+ * The text can come from the command buffer, a remote client, or stdin.
+ */
+void Cmd_ExecuteString(char *text, cmd_source_t src);
+#endif
+#ifdef QW_HACK
+/*
+ * Parses a single line of text into arguments and tries to execute it as if
+ * it was typed at the console
+ */
+void Cmd_ExecuteString(char *text);
+#endif
+
 void Cmd_Init(void);
 
 void Cmd_AddCommand(const char *cmd_name, xcommand_t function);
@@ -96,10 +122,6 @@
 // register commands and functions to call for them.
 // The cmd_name is referenced later, so it should not be in temp memory
 
-// FIXME - different behaviour from NQ - Tag: QW_CMD_SOURCE
-// if function is NULL, the command will be forwarded to the server
-// as a clc_stringcmd instead of executed locally
-
 qboolean Cmd_Exists(char *cmd_name);
 qboolean Cmd_Alias_Exists(char *cmd_name);
 // used by the cvar code to check for cvar / command name overlap
@@ -122,17 +144,20 @@
 // Takes a null terminated string.  Does not need to be /n terminated.
 // breaks the string up into arg tokens.
 
-void Cmd_ExecuteString(char *text);
-
-// Parses a single line of text into arguments and tries to execute it.
-// as if it was typed at the console
-
 void Cmd_ForwardToServer(void);
 
 // adds the current command line as a clc_stringcmd to the client message.
 // things like godmode, noclip, etc, are commands directed to the server,
 // so when they are typed in at the console, they will need to be forwarded.
 
+#ifdef NQ_HACK
+void Cmd_Print(char *text);
+
+// used by command functions to send output to either the graphics console or
+// passed as a print message to the client
+#endif
+#ifdef QW_HACK
 void Cmd_StuffCmds_f(void);
+#endif
 
 #endif /* CMD_H */
